@@ -2,12 +2,15 @@
 API calls for flowcharts
 """
 
-from seamm_dashboard.models import Flowchart, FlowchartSchema
+from seamm_datastore.database.models import Flowchart
+from seamm_datastore.database.schema import FlowchartSchema
 from flask import Response
 from flask_jwt_extended import jwt_required
 
 from seamm_dashboard import authorize
 
+import json
+
 __all__ = ["get_flowcharts", "get_flowchart", "get_cytoscape"]
 
 
@@ -20,14 +23,24 @@ def get_flowcharts(description=None, limit=None):
 
     if description is not None:
         flowcharts = Flowchart.query.filter(
-            Flowchart.description.contains(description), Flowchart.authorized("read")
+            Flowchart.description.contains(description)
         ).limit(limit)
     else:
-        flowcharts = Flowchart.query.filter(Flowchart.authorized("read")).limit(limit)
+        flowcharts = Flowchart.query.limit(limit)
+
+    authorized_flowcharts = []
+    for flowchart in flowcharts:
+        if authorize.read(flowchart):
+            authorized_flowcharts.append(flowchart)
+        else:
+            for project in flowchart.projects:
+                if authorize.read(project):
+                    authorized_flowcharts.append(flowchart)
+                    break
 
     flowcharts_schema = FlowchartSchema(many=True)
 
-    return flowcharts_schema.dump(flowcharts), 200
+    return flowcharts_schema.dump(authorized_flowcharts), 200
 
 
 @jwt_required(optional=True)
@@ -44,7 +57,17 @@ def get_flowchart(id):
     if flowchart is None:
         return Response(status=404)
 
-    if not authorize.read(flowchart):
+    authorized = False
+    if authorize.read(flowchart):
+        authorized = True
+
+    if not authorized:
+        for project in flowchart.projects:
+            if authorize.read(project):
+                authorized = True
+                break
+
+    if not authorized:
         return Response(status=401)
 
     flowchart_schema = FlowchartSchema(many=False)
@@ -62,12 +85,24 @@ def get_cytoscape(id, flowchartKeys=None):
     if flowchart is None:
         return Response(status=404)
 
-    if not authorize.read(flowchart):
+    authorized = False
+
+    if authorize.read(flowchart):
+        authorized = True
+    if not authorized:
+        for project in flowchart.projects:
+            if authorize.read(project):
+                authorized = True
+                break
+
+    if not authorized:
         return Response(status=401)
 
     important_stuff = {}
     important_stuff = flowchart.json
-    # description = important_stuff['nodes'][0]['attributes']['_description']
+
+    if isinstance(important_stuff, str):
+        important_stuff = json.loads(flowchart.json)
 
     elements = []
 
